Rudimentary data transforms and algorithms
==========================================

.. autofunction:: satella.coding.transforms.unpack_dict

.. autofunction:: satella.coding.transforms.is_subset

.. autoclass:: satella.coding.transforms.merge_list

.. autofunction:: satella.coding.transforms.hashables_to_int

.. autofunction:: satella.coding.transforms.linear_interpolate

.. autofunction:: satella.coding.transforms.intify

.. autofunction:: satella.coding.transforms.jsonify

.. autofunction:: satella.coding.transforms.percentile

.. autofunction:: satella.coding.transforms.b64encode

.. autofunction:: satella.coding.transforms.list_values_to_indices

pad_to_multiple_of_length
-------------------------

.. autofunction:: satella.coding.transforms.pad_to_multiple_of_length


split_shuffle_and_join
----------------------

.. autofunction:: satella.coding.transforms.split_shuffle_and_join


one_tuple
---------

.. autofunction:: satella.coding.transforms.one_tuple

stringify
---------

Make both keys and values (if dict), values (if list) or make an object a string by passing them through stringify function.

.. autofunction:: satella.coding.transforms.stringify


clip
---------

.. autofunction:: satella.coding.transforms.clip


merge_series
------------

.. autoclass:: satella.coding.transforms.merge_series
    :members:

